# coding: utf-8

"""
    Cloudability

     Module containing a class for interacting with the Cloudability.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME="cloudability"
VERSION='0.1.3'
REQUIRES=[
    'pandas==1.2.4',
    'requests>=2.25.1'
]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="Cloudability",
    author="Pearson Service Insights",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PCM", "PSI", "Cloudability"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing a class for interacting with the Cloudability.   # noqa: E501
    """
)
